@@ -44,6 +44,7 @@ class DiscountLineDetail(QuickbooksBaseObject):
         "Discount": DiscountOverride,
         "ClassRef": Ref,
         "TaxCodeRef": Ref,
+        "DiscountAccountRef": Ref
     }
 
     def __init__(self):
@@ -52,6 +53,8 @@ class DiscountLineDetail(QuickbooksBaseObject):
         self.Discount = None
         self.ClassRef = None
         self.TaxCodeRef = None
+        self.PercentBased = False
+        self.DiscountPercent = 0
 
 
 class DiscountLine(DetailLine):
@@ -82,7 +85,7 @@ class SubtotalLine(DetailLine):
 
     def __init__(self):
         super(SubtotalLine, self).__init__()
-        self.DetailType = "SubtotalLineDetail"
+        self.DetailType = "SubTotalLineDetail"
         self.SubtotalLineDetail = None
 
 
@@ -157,19 +160,8 @@ class GroupLine(DetailLine):
 
     def __init__(self):
         super(GroupLine, self).__init__()
-        self.DetailType = "SalesItemLineDetail"
-        self.SalesItemLineDetail = None
-
-
-class DescriptionLineDetail(QuickbooksBaseObject):
-    class_dict = {
-        "TaxCodeRef": Ref,
-    }
-
-    def __init__(self):
-        super(DescriptionLineDetail, self).__init__()
-        self.ServiceDate = ""
-        self.TaxCodeRef = None
+        self.DetailType = "GroupLineDetail"
+        self.GroupLineDetail = None
 
 
 class DescriptionOnlyLine(DetailLine):
@@ -179,7 +171,7 @@ class DescriptionOnlyLine(DetailLine):
 
     def __init__(self):
         super(DescriptionOnlyLine, self).__init__()
-        self.DetailType = "DescriptionLineDetail"
+        self.DetailType = "DescriptionOnly"
         self.DescriptionLineDetail = None
 
 
@@ -219,6 +211,28 @@ class AccountBasedExpenseLine(DetailLine):
         self.AccountBasedExpenseLineDetail = None
 
 
+@python_2_unicode_compatible
+class TDSLineDetail(QuickbooksBaseObject):
+    def __init__(self):
+        super(TDSLineDetail, self).__init__()
+        self.TDSSectionTypeId = None
+
+    def __str__(self):
+        return self.TDSSectionTypeId
+
+
+class TDSLine(DetailLine):
+    class_dict = {
+        "TDSLineDetail": TDSLineDetail
+    }
+
+    def __init__(self):
+        super(TDSLine, self).__init__()
+
+        self.DetailType = "TDSLineDetail"
+        self.TDSLineDetail = None
+
+
 class ItemBasedExpenseLineDetail(QuickbooksBaseObject):
     class_dict = {
         "ItemRef": Ref,
@@ -231,7 +245,7 @@ class ItemBasedExpenseLineDetail(QuickbooksBaseObject):
 
     def __init__(self):
         super(ItemBasedExpenseLineDetail, self).__init__()
-        self.BillableStatus = ""
+        self.BillableStatus = None
         self.UnitPrice = 0
         self.TaxInclusiveAmt = 0
         self.Qty = 0
